/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */
import {
	TextControl,
	Panel,
	PanelBody,
	PanelRow,
	SelectControl
} from '@wordpress/components';

import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import {
    useBlockProps,
    ColorPalette,
    InspectorControls,
} from '@wordpress/block-editor';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @param {Object}   props               Properties passed to the function.
 * @param {Object}   props.attributes    Available block attributes.
 * @param {Function} props.setAttributes Function that updates individual attributes.
 *
 * @return {WPElement} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {

	const onChangeBGColor = ( hexColor ) => {
		setAttributes( { bg_color: hexColor } );
	};

	const onChangeTextColor = ( hexColor ) => {
		setAttributes( { text_color: hexColor } );
	};

	const blockEditorStyle = {
		backgroundColor: attributes.bg_color,
		color: attributes.text_color
	};

	const blockProps = useBlockProps( { style: blockEditorStyle } );

	const termsOptions = window.storyList.terms;

	return (
		<div { ...blockProps }>
			<InspectorControls key="setting">
				<Panel header={ __( 'Relatos', 'story-list' ) }>
					<PanelBody title={ __( 'Cores do bloco', 'story-list' ) } initialOpen={ false }>
						<PanelRow className="edit-post-story-list">
							<div id="story-list-controls">
								<fieldset>
									<legend className="blocks-base-control__label">
										{ __( 'Cor de fundo do bloco', 'story-list' ) }
									</legend>
									<ColorPalette
										value={ attributes.bg_color }
										onChange={ onChangeBGColor }
									/>
								</fieldset>
								<fieldset>
									<legend className="blocks-base-control__label">
										{ __( 'Cor do texto', 'story-list' ) }
									</legend>
									<ColorPalette
										value={ attributes.text_color }
										onChange={ onChangeTextColor }
									/>
								</fieldset>
							</div>
						</PanelRow>
					</PanelBody>
					<PanelBody title={ __( 'Tipo', 'story-list' ) } initialOpen={ false }>
						<PanelRow className="edit-type-story-list">
							<SelectControl
								label={ __( 'Selecione o tipo de relato', 'story-list' ) }
								value={ attributes.term_id }
								options={ termsOptions }
								onChange={ ( val ) => setAttributes( { term_id: val } ) }
								__nextHasNoMarginBottom
							/>
						</PanelRow>
					</PanelBody>
				</Panel>
			</InspectorControls>

			<div className="aa">
				<TextControl
					label= { __( 'Título do bloco', 'story-list' ) }
					value={ attributes.title }
					onChange={ ( val ) => setAttributes( { title: val } ) }
				/>

				<TextControl
					label= { __( 'Descrição do bloco', 'story-list' ) }
					value={ attributes.description }
					onChange={ ( val ) => setAttributes( { description: val } ) }
				/>
			</div>
		</div>
	);
}
